@@ -1,7 +1,7 @@
 const APP_DISPLAY_NAME = "NoScript";
 const APP_NAME = "noscript";
 const APP_PACKAGE = "/informaction/noscript";
-const APP_VERSION = "1.9.2.8";
+const APP_VERSION = "1.9.9.69";
 
 const APP_PREFS_FILE="defaults/preferences/noscript.js";
 const APP_XPCOM_SERVICE="components/noscriptService.js";
@@ -9,47 +9,29 @@ const APP_JAR_FILE = "noscript.jar";
 const APP_CONTENT_FOLDER = "content/noscript/";
 const APP_LOCALES = [
   "es-ES","cs-CZ","pl-PL","ja-JP","ca-AD","pt-PT","pt-BR","de-DE","nb-NO",
-  "fi-FI","fr-FR","it-IT","nl-NL","tr-TR","zh-CN","ru-RU","bg-BG","ro-RO",
-  "uk-UA", "th-TH", "fa-IR", "el-GR", "hr-HR", "he-IL", "be-BY", "vi-VN",
-  "sk-SK", "hu-HU", "mk-MK", "da-DK", "sv-SE", "lt-LT", "zh-TW", // "sr-YU",
-  "id-ID", "es-AR", "ar", "de-AT", "ko-KR", "et-EE", // "sl-SI",
+  "fi-FI","fr","it-IT","nl-NL","tr-TR","zh-CN","ru-RU","bg-BG","ro",
+  "uk-UA", "th-TH", "fa-IR", "el-GR", "hr-HR", "he-IL", "be-BY", "vi",
+  "sk-SK", "hu-HU", "mk-MK", "da-DK", "sv-SE", "lt-LT", "zh-TW", 
+  "id-ID", "es-AR", "ar", "de-AT", "ko-KR", "et-EE", "en-GB",
   "en-US"
   ];
 
 const APP_SUCCESS_MESSAGE = APP_DISPLAY_NAME + " should now be available when you restart the browser.";
 
-const INST_TO_PROFILE = "Do you wish to install " + APP_DISPLAY_NAME + 
-  " to your profile?\nIf you are in doubt, this is the preferred option: click OK.\n(Click Cancel if you want " + 
-  APP_DISPLAY_NAME + " installing to the Mozilla directory.)";
-
-var instToProfile = true;
+var instToProfile = false;
 
 myPerformInstall(false);
 
 function myPerformInstall(secondTry) {
   
-  
-  
   var err;
   initInstall(APP_NAME, APP_PACKAGE, APP_VERSION);
-  
-  function chromeExistsIn(folder) {
-    var chrome = getFolder(folder, APP_JAR_FILE);
-    var isDir = File.isDirectory(chrome);
-    if (!isDir) isDir = chrome && chrome.toString().slice(-1) == '/';
-    if (isDir)
-      File.dirRemove(chrome);  
-    return !chrome || !isDir;
-  }
-  
+  var profChrome = getFolder("Profile", "chrome");
   if(!secondTry) {  
-    // profile installs only work since 2003-03-06
-    instToProfile = chromeExistsIn(getFolder("Profile", "chrome")) ||
-      !chromeExistsIn(getFolder("chrome")) && 
-        buildID > 2003030600 && !!confirm(INST_TO_PROFILE);
+    File.remove(getFolder(profChrome, APP_JAR_FILE));
   }
 
-  var chromef = instToProfile ? getFolder("Profile", "chrome") : getFolder("chrome");
+  var chromef = instToProfile ? profChrome : getFolder("chrome");
   err = addFile(APP_PACKAGE, APP_VERSION, "chrome/" + APP_JAR_FILE, chromef, null);
   
   if(APP_PREFS_FILE && (err == SUCCESS) ) {
@@ -73,10 +55,11 @@ function myPerformInstall(secondTry) {
   
     registerChrome(CONTENT | chromeFlag, jar, APP_CONTENT_FOLDER);
     var localesCount=APP_LOCALES.length;
-    if(localesCount>0) {
-      registerChrome(LOCALE | chromeFlag, jar, "content/noscript/"+APP_LOCALES[--localesCount]+"/");
+    if(localesCount > 0) {
+      registerChrome(LOCALE | chromeFlag, jar, "content/noscript/" + APP_LOCALES[--localesCount] + "/");
+      var locale;
       while(localesCount-- >0) {
-        registerChrome(LOCALE  | chromeFlag, jar, "locale/"+APP_LOCALES[localesCount]+"/noscript/");
+        registerChrome(LOCALE  | chromeFlag, jar, "locale/"+ APP_LOCALES[localesCount] +"/noscript/");
       }
     }
     registerChrome(SKIN | chromeFlag, jar, "skin/classic/noscript/");
